@@ -1,6 +1,6 @@
 use crate::opt::{ProcessCategory, SystemCategory};
 use crate::types::ProcessInfo;
-use crate::{CpuInfo, GpuInfo, Pid};
+use crate::{CpuInfo, GpuInfo, PhysicalCpuInfo, Pid};
 use serde::Serialize;
 use std::fs::File;
 use std::path::Path;
@@ -12,6 +12,7 @@ pub fn consume<P: AsRef<Path>>(
     timestamps: &[chrono::DateTime<chrono::Local>],
     processes: &[ProcessInfo],
     cpu_info: &[CpuInfo],
+    physical_cpu_info: &[PhysicalCpuInfo],
     gpu_info: &[GpuInfo],
 ) {
     let file = File::create(path).unwrap();
@@ -60,6 +61,20 @@ pub fn consume<P: AsRef<Path>>(
                     });
                 }
             }
+            SystemCategory::CPUTemp => {
+                for info in physical_cpu_info {
+                    json_output.sys_cpu_temp.push(SystemRecord {
+                        records: timestamps
+                            .iter()
+                            .enumerate()
+                            .map(|(i, t)| Record {
+                                timestamp: t.to_rfc3339(),
+                                value: info.temp[i],
+                            })
+                            .collect(),
+                    });
+                }
+            }
             SystemCategory::GPU => {
                 for info in gpu_info {
                     json_output.sys_gpu.push(SystemRecord {
@@ -77,7 +92,8 @@ pub fn consume<P: AsRef<Path>>(
         }
     }
 
-    serde_json::to_writer(file, &json_output).unwrap();
+    serde_json::to_writer(&file, &json_output).unwrap();
+    file.sync_all().unwrap();
 }
 
 #[derive(Serialize)]
@@ -106,35 +122,6 @@ struct JsonOutput {
     gpu: Vec<ProcessRecord>,
     fps: Vec<ProcessRecord>,
     sys_cpu_freq: Vec<SystemRecord>,
+    sys_cpu_temp: Vec<SystemRecord>,
     sys_gpu: Vec<SystemRecord>,
 }
-
-/*
-
-{
-    "cpu": [
-        {
-            "pid": 1,
-            "name": "",
-            "command": "",
-            "records": [
-                {
-                    "timestamp": "<timestamp>",
-                    "value": 1.0,
-                }
-            ]
-        }
-    ],
-    "sys_cpu_freq": [
-        {
-            "records": [
-                {
-                    "timestamp": "<timestamp>",
-                    "value": 1.0,
-                }
-            ]
-        }
-    ]
-}
-
-*/
